@@ -282,7 +282,7 @@ class SecureFlaskApp(Flask):
                 response = render_template(self.__custom_403) if self.__custom_403 \
                                else jsonify(dict(message="Unauthorized")), 403
                 if "cas-object" not in session:
-                    after_login = request.path
+                    after_login = f"{request.path}{_parse_query_string(quoted=True)}"
                     session["cas-after-login"] = after_login
                     response = _login(self.__cas_server_url, self.app_url)
                 else:
@@ -409,7 +409,7 @@ def _login(in_cas_url, in_app_url, db_session=None, security_user_table=None):
     :param in_cas_url:      The CAS server url
     :return:                An appropriate redirect url
     """
-    app_url = f"{in_app_url}{request.full_path}"
+    app_url = f"{in_app_url}{request.path}{_parse_query_string(quoted=True)}"
     redirect_url = f"{in_cas_url}/cas/login?service={app_url}"
     if "ticket" in request.args:
         session["cas-ticket"] = request.args["ticket"]
